@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_core.c,v 1.28 2002/01/31 14:33:12 wensong Exp $
+ * Version:     $Id: ip_vs_core.c,v 1.29 2002/03/25 12:44:35 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -207,9 +207,9 @@ ip_vs_sched_persist(struct ip_vs_service *svc, struct iphdr *iph)
 			}
 
 			/*
-			 * Create a template like <protocol,daddr,0,
-			 * maddr,mport,saddr,sport> for non-ftp service,
-			 * and <protocol,daddr,0,maddr,0,saddr,0>
+			 * Create a template like <protocol,caddr,0,
+			 * vaddr,vport,daddr,dport> for non-ftp service,
+			 * and <protocol,caddr,0,vaddr,0,daddr,0>
 			 * for ftp service.
 			 */
 			if (svc->port != FTPPORT)
@@ -239,8 +239,8 @@ ip_vs_sched_persist(struct ip_vs_service *svc, struct iphdr *iph)
 		/*
 		 * Note: persistent fwmark-based services and persistent
 		 * port zero service are handled here.
-		 * fwmark template: <IPPROTO_IP,daddr,0,fwmark,0,saddr,0>
-		 * port zero template: <protocol,daddr,0,maddr,0,saddr,0>
+		 * fwmark template: <IPPROTO_IP,caddr,0,fwmark,0,daddr,0>
+		 * port zero template: <protocol,caddr,0,vaddr,0,daddr,0>
 		 */
 		if (svc->fwmark)
 			ct = ip_vs_conn_in_get(IPPROTO_IP, snet, 0,
@@ -555,6 +555,10 @@ static int ip_vs_out_icmp(struct sk_buff **skb_p)
 	if (ciph->protocol != IPPROTO_UDP && ciph->protocol != IPPROTO_TCP)
 		return NF_ACCEPT;
 
+	/* Skip non-first embedded TCP/UDP fragments */
+	if (ciph->frag_off & __constant_htons(IP_OFFSET))
+		return NF_ACCEPT;
+
 	/* We need at least TCP/UDP ports here */
 	if (clen < csize + sizeof(struct udphdr))
 		return NF_DROP;
@@ -893,6 +897,10 @@ static int ip_vs_in_icmp(struct sk_buff **skb_p)
 	if (ciph->protocol != IPPROTO_UDP && ciph->protocol != IPPROTO_TCP)
 		return NF_ACCEPT;
 
+	/* Skip non-first embedded TCP/UDP fragments */
+	if (ciph->frag_off & __constant_htons(IP_OFFSET))
+		return NF_ACCEPT;
+
 	/* We need at least TCP/UDP ports here */
 	if (clen < csize + sizeof(struct udphdr))
 		return NF_DROP;
