@@ -5,7 +5,7 @@
  *              high-performance and highly available server based on a
  *              cluster of servers.
  *
- * Version:     $Id: ip_vs_ctl.c,v 1.26 2002/02/27 02:50:18 wensong Exp $
+ * Version:     $Id: ip_vs_ctl.c,v 1.27 2002/03/25 12:44:35 wensong Exp $
  *
  * Authors:     Wensong Zhang <wensong@linuxvirtualserver.org>
  *              Peter Kese <peter.kese@ijs.si>
@@ -861,6 +861,9 @@ static int ip_vs_edit_dest(struct ip_vs_service *svc,
 
 	__ip_vs_update_dest(svc, dest, ur);
 
+	/* call the update_service, because server weight may be changed */
+	svc->scheduler->update_service(svc);
+
 	LeaveFunction(2);
 
 	return 0;
@@ -2044,7 +2047,7 @@ static struct nf_sockopt_ops ip_vs_sockopts = {
 };
 
 
-int __init ip_vs_control_init(void)
+int ip_vs_control_init(void)
 {
 	int ret;
 	int idx;
@@ -2082,7 +2085,7 @@ int __init ip_vs_control_init(void)
 	return 0;
 }
 
-void __exit ip_vs_control_cleanup(void)
+void ip_vs_control_cleanup(void)
 {
 	EnterFunction(2);
 	ip_vs_trash_cleanup();
